<?php

return [
    'number.decimals_separator' => '.',
    'number.thousands_separator' => ' ',
    'None' => 'Nimic',
    'Edit' => 'Modifică',
    'Remove' => 'Șterge',
    'Yes' => 'Da',
    'No' => 'Nu',
    'cancel' => 'anulare',
    'or' => 'sau',
    'Yellow' => 'Galben',
    'Blue' => 'Albastru',
    'Green' => 'Verde',
    'Purple' => 'Violet',
    'Red' => 'Roșu',
    'Orange' => 'Portocaliu',
    'Grey' => 'Gri',
    'Brown' => 'Maro',
    'Deep Orange' => 'Portocaliu închis',
    'Dark Grey' => 'Gri închis',
    'Pink' => 'Roz',
    'Teal' => 'Turcoaz',
    'Cyan' => 'Bleu',
    'Lime' => 'Lime',
    'Light Green' => 'Verde deschis',
    'Amber' => 'Ambră',
    'Save' => 'Salvează',
    'Login' => 'Conectare',
    'Official website:' => 'Site web oficial:',
    'Unassigned' => 'Neatribuit',
    'View this task' => 'Vezi sarcina aceasta',
    'Remove user' => 'Șterge utilizator',
    'Do you really want to remove this user: "%s"?' => 'Vrei să ștergi acest utilizator: "%s" ?',
    'All users' => 'Toți utilizatorii',
    'Username' => 'Nume utilizator',
    'Password' => 'Parolă',
    'Administrator' => 'Administrator',
    'Sign in' => 'Conectare',
    'Users' => 'Utilizatori',
    'Forbidden' => 'Interzis',
    'Access Forbidden' => 'Acces interzis',
    'Edit user' => 'Modifică utilizator',
    'Logout' => 'Deconectare',
    'Bad username or password' => 'Utilizator sau parolă incorectă',
    'Edit project' => 'Modifică proiect',
    'Name' => 'Nume',
    'Projects' => 'Proiecte',
    'No project' => 'Fără proiect',
    'Project' => 'Proiect',
    'Status' => 'Stare',
    'Tasks' => 'Sarcini',
    'Board' => 'Bord',
    'Actions' => 'Actiuni',
    'Inactive' => 'Inactiv',
    'Active' => 'Activ',
    'Unable to update this board.' => 'Nu am putut actualiza acest bord.',
    'Disable' => 'Dezactivează',
    'Enable' => 'Activează',
    'New project' => 'Proiect nou',
    'Do you really want to remove this project: "%s"?' => 'Vrei să ștergi acest proiect: "%s" ?',
    'Remove project' => 'Șterge proiect',
    'Edit the board for "%s"' => 'Modifică bordul pentru "%s"',
    'Add a new column' => 'Adaugă o coloană nouă',
    'Title' => 'Titlu',
    'Assigned to %s' => 'Atribuie lui %s',
    'Remove a column' => 'Șterge o coloană',
    'Unable to remove this column.' => 'Nu pot șterge această coloană.',
    'Do you really want to remove this column: "%s"?' => 'Vrei să ștergi acestă coloană: "%s" ?',
    'Settings' => 'Preferințe',
    'Application settings' => 'Preferințele aplicației',
    'Language' => 'Limbă',
    'Webhook token:' => 'Token de securitate pentru webhook:',
    'API token:' => 'Token de securitate pentru API:',
    'Database size:' => 'Dimensiune bază de date:',
    'Download the database' => 'Descarcă baza de date',
    'Optimize the database' => 'Optimizează baza de date',
    '(VACUUM command)' => '(Comanda VACUUM)',
    '(Gzip compressed Sqlite file)' => '(Fișier Sqlite comprimat cu Gzip)',
    'Close a task' => 'Închide o sarcină',
    'Column' => 'Coloană',
    'Color' => 'Culoare',
    'Assignee' => 'Persoană desemnată',
    'Create another task' => 'Creează altă sarcină',
    'New task' => 'Sarcină nouă',
    'Open a task' => 'Deschide o sarcină',
    'Do you really want to open this task: "%s"?' => 'Vrei să deschizi sarcina: "%s" ?',
    'Back to the board' => 'Înapoi la bord',
    'There is nobody assigned' => 'Nu este desemnată o persoană',
    'Column on the board:' => 'Coloană pe bord: ',
    'Close this task' => 'Închide sarcina',
    'Open this task' => 'Deschide Sarcina',
    'There is no description.' => 'Nu există o descriere.',
    'Add a new task' => 'Adaugă o sarcină nouă',
    'The username is required' => 'Numele este obligatoriu',
    'The maximum length is %d characters' => 'Lungimea maximă este de %d caractere',
    'The minimum length is %d characters' => 'Lungimea minimă este de %d caractere',
    'The password is required' => 'Parola este obligatorie',
    'This value must be an integer' => 'Valoarea trebuie să fie număr întreg',
    'The username must be unique' => 'Utilizatorul trebuie să fie unic',
    'The user id is required' => 'ID-ul de utilizator este obligatoriu',
    'Passwords don\'t match' => 'Parolele nu corespund',
    'The confirmation is required' => 'Confirmarea este obligatorie',
    'The project is required' => 'Proiectul este obligatoriu',
    'The id is required' => 'Identificatorul este obligatoriu',
    'The project id is required' => 'ID-ul proiectului este obligatoriu',
    'The project name is required' => 'Numele proiectului este obligatoriu',
    'The title is required' => 'Titlul este obligatoriu',
    'Settings saved successfully.' => 'Preferințele au fost salvate.',
    'Unable to save your settings.' => 'Nu am putut salva preferințele.',
    'Database optimization done.' => 'Optimizarea bazei de date s-a încheiat.',
    'Your project has been created successfully.' => 'Proiectul dumneavoastră a fost creat cu succes.',
    'Unable to create your project.' => 'Nu am putut crea proiectul dumneavoastră.',
    'Project updated successfully.' => 'Proiectul a fost actualizat.',
    'Unable to update this project.' => 'Nu am putut actualiza proiectul.',
    'Unable to remove this project.' => 'Nu am putut șterge proiectul.',
    'Project removed successfully.' => 'Proiectul a fost șters.',
    'Project activated successfully.' => 'Proiectul a fost activat.',
    'Unable to activate this project.' => 'Nu am putut activa proiectul.',
    'Project disabled successfully.' => 'Proiectul a fost dezactivat.',
    'Unable to disable this project.' => 'Nu am putut dezactiva proiectul',
    'Unable to open this task.' => 'Nu am putut deschide sarcina.',
    'Task opened successfully.' => 'Sarcina a fost deschisă',
    'Unable to close this task.' => 'Nu am putut închide sarcina.',
    'Task closed successfully.' => 'Sarcina a fost închisă.',
    'Unable to update your task.' => 'Nu am putut actualiza sarcina.',
    'Task updated successfully.' => 'Sarcina fost actualizată.',
    'Unable to create your task.' => 'Nu am putut crea sarcina.',
    'Task created successfully.' => 'Sarcina a fost creată.',
    'User created successfully.' => 'Utilizatorul a fost creat.',
    'Unable to create your user.' => 'Nu am putut crea utilizatorul.',
    'User updated successfully.' => 'Utilizatorul a fost actualizat.',
    'User removed successfully.' => 'Utilizatorul a fost șters.',
    'Unable to remove this user.' => 'Nu am putut șterge utilizatorul.',
    'Board updated successfully.' => 'Bordul a fost actualizat.',
    'Ready' => 'Pregătit',
    'Backlog' => 'Restant',
    'Work in progress' => 'În desfășurare',
    'Done' => 'Finalizat',
    'Application version:' => 'Versiunea aplicației:',
    'Id' => 'Id',
    'Public link' => 'Legătură publică',
    'Timezone' => 'Fus orar',
    'Sorry, I didn\'t find this information in my database!' => 'Scuze, nu am găsit informația asta în baza mea de date!',
    'Page not found' => 'Pagina nu a fost găsită',
    'Complexity' => 'Complexitate',
    'Task limit' => 'Limită sarcini.',
    'Task count' => 'Număr de sarcini',
    'User' => 'Utilizator',
    'Comments' => 'Comentarii',
    'Comment is required' => 'Comentariul este obligatoriu',
    'Comment added successfully.' => 'Comentariul a fost adăugat',
    'Unable to create your comment.' => 'Nu am putut crea comentariul.',
    'Due Date' => 'Data scadentă',
    'Invalid date' => 'Dată invalidă',
    'Automatic actions' => 'Acțiuni automatizate',
    'Your automatic action has been created successfully.' => 'Acțiunea automatizată a fost creată.',
    'Unable to create your automatic action.' => 'Nu am putut crea acțiunea automatizată.',
    'Remove an action' => 'Șterge o acțiune',
    'Unable to remove this action.' => 'Nu am putut șterge acțiunea',
    'Action removed successfully.' => 'Acțiunea a fost ștearsă.',
    'Automatic actions for the project "%s"' => 'Acțiuni automatizate pentru proiectul "%s"',
    'Add an action' => 'Adaugă o acțiune',
    'Event name' => 'Nume eveniment',
    'Action' => 'Acțiune',
    'Event' => 'Eveniment',
    'When the selected event occurs execute the corresponding action.' => 'Când are loc evenimentul ales execută acțiunea corespunzătoare.',
    'Next step' => 'Pasul următor',
    'Define action parameters' => 'Definește parametrii acțiunii',
    'Do you really want to remove this action: "%s"?' => 'Vrei să ștergi acțiunea: "%s" ?',
    'Remove an automatic action' => 'Șterge o acțiune automatizată',
    'Assign the task to a specific user' => 'Atribuie sarcina unui utilizator specific',
    'Assign the task to the person who does the action' => 'Atribuie sarcina persoanei care îndeplinește acțiunea',
    'Duplicate the task to another project' => 'Duplichează sarcina în alt proiect',
    'Move a task to another column' => 'Mută sarcina în altă coloană',
    'Task modification' => 'Modificare sarcină',
    'Task creation' => 'Creare sarcină',
    'Closing a task' => 'Închidere sarcină',
    'Assign a color to a specific user' => 'Atribuie o culoare unui utilizator specific',
    'Position' => 'Poziție',
    'Duplicate to project' => 'Duplichează în alt proiect',
    'Duplicate' => 'Duplicare',
    'Link' => 'Legătură',
    'Comment updated successfully.' => 'Comentariu actualizat.',
    'Unable to update your comment.' => 'Nu am putut actualiza comentariul.',
    'Remove a comment' => 'Șterge un comentariu',
    'Comment removed successfully.' => 'Comentariul a fost șters.',
    'Unable to remove this comment.' => 'Nu am putut șterge comentariul.',
    'Do you really want to remove this comment?' => 'Vrei să ștergi acest comentariu?',
    'Current password for the user "%s"' => 'Parola actuală pentru utilizatorul "%s"',
    'The current password is required' => 'Parola actuală este obligatorie',
    'Wrong password' => 'Parolă greșită',
    'Unknown' => 'Necunoscut',
    'Last logins' => 'Ultimele conectări',
    'Login date' => 'Data conectării',
    'Authentication method' => 'Metodă de autentificare',
    'IP address' => 'Adresă IP',
    'User agent' => 'Agent utilizator',
    'Persistent connections' => 'Conexiuni persistente',
    'No session.' => 'Fără sesiune.',
    'Expiration date' => 'Data expirării',
    'Remember Me' => 'Amintește-ți de mine',
    'Creation date' => 'Data creării',
    'Everybody' => 'Toată lumea',
    'Open' => 'Deschis',
    'Closed' => 'Închis',
    'Search' => 'Caută',
    'Nothing found.' => 'Nimic găsit.',
    'Due date' => 'Dată scadentă',
    'Description' => 'Descriere',
    '%d comments' => '%d comentarii',
    '%d comment' => '%d comentariu',
    'Email address invalid' => 'Adresă e-mail invalidă',
    'Your external account is not linked anymore to your profile.' => 'Contul tău extern nu mai este legat cu profilul.',
    'Unable to unlink your external account.' => 'Nu am putut dezlega contul tău extern.',
    'External authentication failed' => 'Autentificarea externă a eșuat',
    'Your external account is linked to your profile successfully.' => 'Contul tău extern a fost legat de profil.',
    'Email' => 'E-mail',
    'Task removed successfully.' => 'Sarcină ștearsă.',
    'Unable to remove this task.' => 'Nu pot șterge sarcina.',
    'Remove a task' => 'Șterge o sarcină',
    'Do you really want to remove this task: "%s"?' => 'Vrei să ștergi sarcina: "%s" ?',
    'Assign automatically a color based on a category' => 'Atribuie automat o culoare bazat pe categorie',
    'Assign automatically a category based on a color' => 'Atribuie automat o categorie bazat pe culoare',
    'Task creation or modification' => 'Creare sau modificare sarcină',
    'Category' => 'Categorie',
    'Category:' => 'Categorie:',
    'Categories' => 'Categorii',
    'Your category has been created successfully.' => 'Categoria a fost creată.',
    'This category has been updated successfully.' => 'Categoria a fost actualizată.',
    'Unable to update this category.' => 'Nu am putut actualiza categoria.',
    'Remove a category' => 'Șterge o categorie',
    'Category removed successfully.' => 'Categoria a fost ștearsă.',
    'Unable to remove this category.' => 'Nu am putut șterge categoria.',
    'Category modification for the project "%s"' => 'Modificarea categoriei pentru proiectul "%s"',
    'Category Name' => 'Numele categoriei',
    'Add a new category' => 'Adaugă o categorie nouă',
    'Do you really want to remove this category: "%s"?' => 'Vrei să ștergi categoria: "%s" ?',
    'All categories' => 'Toate categoriile',
    'No category' => 'Fără categorie',
    'The name is required' => 'Numele este obligatoriu',
    'Remove a file' => 'Șterge un fișier',
    'Unable to remove this file.' => 'Nu am putut șterge fișierul.',
    'File removed successfully.' => 'Fișierul a fost șters.',
    'Attach a document' => 'Atașează un document',
    'Do you really want to remove this file: "%s"?' => 'Vrei să ștergi acest fișier: "%s" ?',
    'Attachments' => 'Atașamente',
    'Edit the task' => 'Modifică sarcina',
    'Add a comment' => 'Adaugă un comentariu',
    'Edit a comment' => 'Modifică un comentariu',
    'Summary' => 'Sumar',
    'Time tracking' => 'Urmărirea timpului',
    'Estimate:' => 'Estimat:',
    'Spent:' => 'Petrecut:',
    'Do you really want to remove this sub-task?' => 'Vrei să ștergi această sub-sarcină?',
    'Remaining:' => 'Rămas:',
    'hours' => 'ore',
    'estimated' => 'estimate',
    'Sub-Tasks' => 'Sub-sarcini',
    'Add a sub-task' => 'Adaugă o sub-sarcină',
    'Original estimate' => 'Estimat original',
    'Create another sub-task' => 'Creează altă sub-sarcină',
    'Time spent' => 'Timp petrecut',
    'Edit a sub-task' => 'Modifică o sub-sarcină',
    'Remove a sub-task' => 'Șterge o sub-sarcină',
    'The time must be a numeric value' => 'Timpul trebuie să fie o valoare numerică',
    'Todo' => 'De făcut',
    'In progress' => 'În curs',
    'Sub-task removed successfully.' => 'Sub-sarcină ștearsă.',
    'Unable to remove this sub-task.' => 'Nu am putut șterge sub-sarcina.',
    'Sub-task updated successfully.' => 'Sub-sarcină actualizată.',
    'Unable to update your sub-task.' => 'Nu am putut actualiza sub-sarcina.',
    'Unable to create your sub-task.' => 'Nu am putut crea sub-sarcina.',
    'Maximum size: ' => 'Dimensiune maximă: ',
    'Display another project' => 'Afișează alt proiect',
    'Created by %s' => 'Creat de %s',
    'Tasks Export' => 'Exportă sarcini',
    'Start Date' => 'Data pornirii',
    'Execute' => 'Execută',
    'Task Id' => 'ID Sarcină',
    'Creator' => 'Creator',
    'Modification date' => 'Data modificării',
    'Completion date' => 'Data finalizării',
    'Clone' => 'Clonează',
    'Project cloned successfully.' => 'Proiectul a fost clonat.',
    'Unable to clone this project.' => 'Nu am putut clona proiectul.',
    'Enable email notifications' => 'Activează notificarile pe e-mail',
    'Task position:' => 'Poziția sarcinii:',
    'The task #%d has been opened.' => 'Sarcina #%d a fost deschisă.',
    'The task #%d has been closed.' => 'Sarcina #%d a fost închisă.',
    'Sub-task updated' => 'Sub-sarcină actualizată',
    'Title:' => 'Titlu:',
    'Status:' => 'Stare:',
    'Assignee:' => 'Atribuire:',
    'Time tracking:' => 'Gestionarea timpului:',
    'New sub-task' => 'Sub-sarcină nouă',
    'New attachment added "%s"' => 'Atașament nou adăugat "%s"',
    'New comment posted by %s' => 'Comentariu nou postat de "%s"',
    'New comment' => 'Comentariu nou',
    'Comment updated' => 'Comentariu actualizat',
    'New subtask' => 'Sub-sarcină nouă',
    'I only want to receive notifications for these projects:' => 'Vreau să primesc notificări numai pentru acele proiecte:',
    'view the task on Kanboard' => 'vezi sarcina pe Kanboard',
    'Public access' => 'Acces public',
    'Disable public access' => 'Dezactivează accesul public',
    'Enable public access' => 'Activează accesul public',
    'Public access disabled' => 'Accesul public dezactivat',
    'Move the task to another project' => 'Mută sarcina în alt proiect',
    'Move to project' => 'Mută în alt proiect',
    'Do you really want to duplicate this task?' => 'Vrei să duplichezi această sarcină?',
    'Duplicate a task' => 'Duplichează o sarcină',
    'External accounts' => 'Conturi externe',
    'Account type' => 'Tip de cont',
    'Local' => 'Local',
    'Remote' => 'La distanță',
    'Enabled' => 'Activat',
    'Disabled' => 'Dezactivat',
    'Login:' => 'Utilizator:',
    'Full Name:' => 'Nume :',
    'Email:' => 'E-mail :',
    'Notifications:' => 'Notificări:',
    'Notifications' => 'Notificări',
    'Account type:' => 'Tip de cont:',
    'Edit profile' => 'Modifică profilul',
    'Change password' => 'Schimbă parola',
    'Password modification' => 'Modificare parolă',
    'External authentications' => 'Autentificări externe',
    'Never connected.' => 'Niciodată conectat.',
    'No external authentication enabled.' => 'Nici o autentificare externă activă.',
    'Password modified successfully.' => 'Parolă modificată.',
    'Unable to change the password.' => 'Nu am putut modifica parola.',
    'Change category' => 'Schimbă categoria',
    '%s updated the task %s' => '%s a actualizat sarcina %s',
    '%s opened the task %s' => '%s a deschis sarcina %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s a mutat sarcina %s la poziția #%d în coloana "%s"',
    '%s moved the task %s to the column "%s"' => '%s a mutat sarcina %s în coloana "%s"',
    '%s created the task %s' => '%s a creat sarcina %s',
    '%s closed the task %s' => '%s a închis sarcina %s',
    '%s created a subtask for the task %s' => '%s a creat o sub-sarcină pentru sarcina %s',
    '%s updated a subtask for the task %s' => '%s a actualizat o sub-sarcină pentru sarcina %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Atribuit lui %s cu o estimare de %s/%s h',
    'Not assigned, estimate of %sh' => 'Nimeni atribuit, estimare de %s h',
    '%s updated a comment on the task %s' => '%s a actualizat u comentariu în sarcina %s',
    '%s commented the task %s' => '%s a comentat în sarcina %s',
    '%s\'s activity' => 'Activitatea pentru %s',
    'RSS feed' => 'Flux RSS',
    '%s updated a comment on the task #%d' => '%s a actualizat un comentariu în sarcina #%d',
    '%s commented on the task #%d' => '%s a comentat în sarcina #%d',
    '%s updated a subtask for the task #%d' => '%s a actualizat o sub-sarcină în sarcina #%d',
    '%s created a subtask for the task #%d' => '%s a creat o sub-sarcină în sarcina #%d',
    '%s updated the task #%d' => '%s a actualizat sarcina #%d',
    '%s created the task #%d' => '%s a creat sarcina #%d',
    '%s closed the task #%d' => '%s a închis sarcina #%d',
    '%s opened the task #%d' => '%s a deschis sarcina #%d',
    'Activity' => 'Activitate',
    'Default values are "%s"' => 'Valorile implicite sunt "%s"',
    'Default columns for new projects (Comma-separated)' => 'Coloane implicite pentru proiectele noi (Separate prin virgulă)',
    'Task assignee change' => 'Modificare persoană desemnată sarcinii',
    '%s changed the assignee of the task #%d to %s' => '%s a schimbat persoana desemnată sarcinii #%d lui %s',
    '%s changed the assignee of the task %s to %s' => '%s a schimbat persoana desemnată sarcinii %s lui %s',
    'New password for the user "%s"' => 'Parolă nouă pentru utilizatorul "%s"',
    'Choose an event' => 'Alege un eveniment',
    'Create a task from an external provider' => 'Creează o sarcină de la un furnizor extern',
    'Change the assignee based on an external username' => 'Schimbă persoana desemnată bazat pe un nume de utilizator extern',
    'Change the category based on an external label' => 'Schimbă categoria bazat pe o etichetă externă',
    'Reference' => 'Referință',
    'Label' => 'Etichetă',
    'Database' => 'Bază de date',
    'About' => 'Despre',
    'Database driver:' => 'Tip de bază de date:',
    'Board settings' => 'Preferințe bord',
    'Webhook settings' => 'Preferințe webhook',
    'Reset token' => 'Resetare token de securitate',
    'API endpoint:' => 'URL-ul pentru API:',
    'Refresh interval for personal board' => 'Interval de reîmprospătare pentru bord privat',
    'Refresh interval for public board' => 'Interval de reîmprospătare pentru bord public',
    'Task highlight period' => 'Perioada de evidențiere a sarcinii',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Durata în secunde pentru a considera o sarcină recent modificată (0 pentru dezactivare, 2 zile implicit)',
    'Frequency in second (60 seconds by default)' => 'Frecvență în secunde (60 secunde implicit)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frecvență în secunde (0 pentru dezactivare, 10 secunde implicit)',
    'Application URL' => 'URL-ul aplicației',
    'Token regenerated.' => 'Token de securitate regenerat.',
    'Date format' => 'Formatare dată',
    'ISO format is always accepted, example: "%s" and "%s"' => 'Formatul ISO este întotdeauna acceptat, exemplu: "%s" și "%s"',
    'New personal project' => 'Proiect privat nou',
    'This project is personal' => 'Acest proiect este privat',
    'Add' => 'Adaugă',
    'Start date' => 'Dată pornire',
    'Time estimated' => 'Timp estimat',
    'There is nothing assigned to you.' => 'Nu îți este atribuit nimic.',
    'My tasks' => 'Sarcinile mele',
    'Activity stream' => 'Flux de activitate',
    'Dashboard' => 'Bord',
    'Confirmation' => 'Confirmare',
    'Webhooks' => 'Webhook-uri',
    'API' => 'API',
    'Create a comment from an external provider' => 'Creează un comentariu de la un furnizor extern',
    'Project management' => 'Gestionare proiect',
    'Columns' => 'Coloane',
    'Task' => 'Sarcini',
    'Percentage' => 'Procentaj',
    'Number of tasks' => 'Număr de sarcini',
    'Task distribution' => 'Distribuția sarcinilor',
    'Analytics' => 'Analitică',
    'Subtask' => 'Sub-sarcină',
    'User repartition' => 'Repartizare utilizatori',
    'Clone this project' => 'Clonează proiectul',
    'Column removed successfully.' => 'Coloana a fost ștearsă.',
    'Not enough data to show the graph.' => 'Nu sunt destule date pentru afișarea graficului.',
    'Previous' => 'Anterior',
    'The id must be an integer' => 'ID-ul trebuie să fie un număr întreg',
    'The project id must be an integer' => 'ID-ul proiectului trebuie să fie un număr întreg',
    'The status must be an integer' => 'Starea trebuie să fie un număr întreg',
    'The subtask id is required' => 'ID-ul sub-sarcinii este obligatoriu',
    'The subtask id must be an integer' => 'ID-ul sub-sarcinii trebuie sa fie un număr întreg',
    'The task id is required' => 'ID-ul sarcinii este obligatoriu',
    'The task id must be an integer' => 'ID-ul sarcinii trebuie să fie un număr întreg',
    'The user id must be an integer' => 'ID-ul utilizatorului trebuie să fie un număr întreg',
    'This value is required' => 'Valoarea aceasta este obligatorie',
    'This value must be numeric' => 'Valoarea aceasta trebuie să fie numerică',
    'Unable to create this task.' => 'Nu am putut crea sarcina',
    'Cumulative flow diagram' => 'Diagrama fluxului cumulat',
    'Daily project summary' => 'Rezumatul zilnic al proiectului',
    'Daily project summary export' => 'Export rezumat zilnic al proiectului',
    'Exports' => 'Exporturi',
    'This export contains the number of tasks per column grouped per day.' => 'Acest export conține numărul de sarcini per coloană grupat pe zile.',
    'Active swimlanes' => 'Culoare active',
    'Add a new swimlane' => 'Adaugă culoar nou',
    'Default swimlane' => 'Culoar implicit',
    'Do you really want to remove this swimlane: "%s"?' => 'Vrei să ștergi culoarul: "%s" ?',
    'Inactive swimlanes' => 'Culoare inactive',
    'Remove a swimlane' => 'Șterge un culoar',
    'Swimlane modification for the project "%s"' => 'Modificarea culoarului pentru proiectul "%s"',
    'Swimlane removed successfully.' => 'Culoarul a fost șters',
    'Swimlanes' => 'Culoare',
    'Swimlane updated successfully.' => 'Culoar actualizat.',
    'Unable to remove this swimlane.' => 'Nu am putut șterge culoarul.',
    'Unable to update this swimlane.' => 'Nu am putut actualiza culoarul.',
    'Your swimlane has been created successfully.' => 'Culoarul a fost creat.',
    'Example: "Bug, Feature Request, Improvement"' => 'Exemplu: "Incident, Cere caracteristică, Îmbunătățire"',
    'Default categories for new projects (Comma-separated)' => 'Categorii implicite pentru proiecte noi (Separate prin virgulă)',
    'Integrations' => 'Integrări',
    'Integration with third-party services' => 'Integrări cu servicii externe',
    'Subtask Id' => 'ID sub-sarcină',
    'Subtasks' => 'Sub-sarcini',
    'Subtasks Export' => 'Export sub-sarcini',
    'Task Title' => 'Titlu sarcină',
    'Untitled' => 'Fără titlu',
    'Application default' => 'Implicit din aplicație',
    'Language:' => 'Limbă:',
    'Timezone:' => 'Fus orar:',
    'All columns' => 'Toate coloanele',
    'Next' => 'Următor',
    '#%d' => '#%d',
    'All swimlanes' => 'Toate culoarele',
    'All colors' => 'Toate culorile',
    'Moved to column %s' => 'Mutat în coloana %s',
    'User dashboard' => 'Bordul utilizatorului',
    'Allow only one subtask in progress at the same time for a user' => 'Permite o singură sub-sarcină în derulare simultană pentru un utilizator',
    'Edit column "%s"' => 'Modifică coloana "%s"',
    'Select the new status of the subtask: "%s"' => 'Alege noua stare a sarcinii: "%s"',
    'Subtask timesheet' => 'Pontajul sub-sarcinii',
    'There is nothing to show.' => 'Nimic de afișat',
    'Time Tracking' => 'Urmărirea timpului',
    'You already have one subtask in progress' => 'Deja ai o sub-sarcină în desfășurare',
    'Which parts of the project do you want to duplicate?' => 'Care părți ale proiectului vrei să fie duplicate?',
    'Disallow login form' => 'Interzice formularul de autentificare',
    'Start' => 'Start',
    'End' => 'Final',
    'Task age in days' => 'Vârsta sarcinii în zile',
    'Days in this column' => 'Zile în această coloană',
    '%dd' => '%d z',
    'Add a new link' => 'Adaugă legătură nouă',
    'Do you really want to remove this link: "%s"?' => 'Vrei să ștergi legătura: "%s" ?',
    'Do you really want to remove this link with task #%d?' => 'Vrei să ștergi legătura cu sarcina #%d ?',
    'Field required' => 'Câmp obligatoriu',
    'Link added successfully.' => 'Legătură adăugată.',
    'Link updated successfully.' => 'Legătură actualizată.',
    'Link removed successfully.' => 'Legătură ștearsă.',
    'Link labels' => 'Etichete de legături',
    'Link modification' => 'Modificare legătură',
    'Opposite label' => 'Etichetă opusă',
    'Remove a link' => 'Șterge o legătură',
    'The labels must be different' => 'Etichetele trebuie să difere',
    'There is no link.' => 'Nu există legătură.',
    'This label must be unique' => 'Eticheta trebuie să fie unică',
    'Unable to create your link.' => 'Nu pot crea legătura.',
    'Unable to update your link.' => 'Nu pot actualiza legătura.',
    'Unable to remove this link.' => 'Nu pot șterge legătura.',
    'relates to' => 'se leagă de',
    'blocks' => 'blochează',
    'is blocked by' => 'este blocat de',
    'duplicates' => 'duplichează',
    'is duplicated by' => 'este duplicat de',
    'is a child of' => 'este element moștenitor al',
    'is a parent of' => 'este element parental al',
    'targets milestone' => 'vizează țelul',
    'is a milestone of' => 'este un țel a',
    'fixes' => 'corectează',
    'is fixed by' => 'este corectat de',
    'This task' => 'Această sarcină',
    '<1h' => '< 1 h',
    '%dh' => '%d h',
    'Expand tasks' => 'Extinde sarcinile',
    'Collapse tasks' => 'Restrânge sarcinile',
    'Expand/collapse tasks' => 'Extinde/restrânge sarcinile',
    'Close dialog box' => 'Închide dialogul',
    'Submit a form' => 'Depune un formular',
    'Board view' => 'Vizualizare bord',
    'Keyboard shortcuts' => 'Scurtături de tastatură',
    'Open board switcher' => 'Deschide comutatorul de bord',
    'Application' => 'Aplicație',
    'Compact view' => 'Vizualizare restrânsă',
    'Horizontal scrolling' => 'Derulare orizontală',
    'Compact/wide view' => 'Vizualizare compactă/lată',
    'Currency' => 'Monedă',
    'Personal project' => 'Proiect privat',
    'AUD - Australian Dollar' => 'AUD - Dolar australian',
    'CAD - Canadian Dollar' => 'CAD - Dolar canadian',
    'CHF - Swiss Francs' => 'CHF - Franc elvetian',
    'Custom Stylesheet' => 'Stylesheet personalizat',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Liră sterlină',
    'INR - Indian Rupee' => 'INR - Rupie indiană',
    'JPY - Japanese Yen' => 'JPY - Yen japonez',
    'NZD - New Zealand Dollar' => 'NZD - Dolar neo-zeelandez',
    'PEN - Peruvian Sol' => 'PEN - Sol Peruvian',
    'RSD - Serbian dinar' => 'RSD - Dinar sârbesc',
    'CNY - Chinese Yuan' => 'CNY - Yuan chinez',
    'USD - US Dollar' => 'USD - Dolar american',
    'VES - Venezuelan Bolívar' => 'VES - Bolívar Venezuelan',
    'Destination column' => 'Coloana destinație',
    'Move the task to another column when assigned to a user' => 'Mută sarcina în altă coloană când este atribuită unui utilizator',
    'Move the task to another column when assignee is cleared' => 'Mută sarcina în altă coloană când este eliberată atribuirea',
    'Source column' => 'Coloana sursă',
    'Transitions' => 'Tranzitii',
    'Executer' => 'Executant',
    'Time spent in the column' => 'Timp petrecut în coloană',
    'Task transitions' => 'Tranzițiile sarcinilor',
    'Task transitions export' => 'Exportă tranzițiile sarcinilor',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Acest raport conține toate mutările de coloană pentru sarcinile cu data, utilizatorul și timpul petrecut pentru fiecare tranziție.',
    'Currency rates' => 'Rate de schimb',
    'Rate' => 'Rată',
    'Change reference currency' => 'Schimbă moneda de referință',
    'Reference currency' => 'Moneda de referință',
    'The currency rate has been added successfully.' => 'Rata de schimb a fost adăugată.',
    'Unable to add this currency rate.' => 'Nu am putut adăuga rata de schimb',
    'Webhook URL' => 'URL pentru webhook',
    '%s removed the assignee of the task %s' => '%s a eliberat persoana atribuită sarcinii %s',
    'Information' => 'Informații',
    'Check two factor authentication code' => 'Verificare cod autentificare în doi factori',
    'The two factor authentication code is not valid.' => 'Codul de autentificare în doi factori nu este valid.',
    'The two factor authentication code is valid.' => 'Codul de autentificare în doi factori este valid.',
    'Code' => 'Cod',
    'Two factor authentication' => 'Autentificare în doi factori',
    'This QR code contains the key URI: ' => 'Codul QR contine URI-ul cheii: ',
    'Check my code' => 'Verifică codul meu',
    'Secret key: ' => 'Cheia secretă: ',
    'Test your device' => 'Testează dispozitivul tău',
    'Assign a color when the task is moved to a specific column' => 'Atribuie o culoare când sarcina este mutată într-o anumită coloană',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Graficul progresului',
    'This chart show the task complexity over the time (Work Remaining).' => 'Acest grafic arată complexitatea sarcinii de-a lungul timpului (munca rămasă).',
    'Screenshot taken %s' => 'Captură de ecran %s',
    'Add a screenshot' => 'Adaugă captură de ecran',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Faceți o captura de ecran si apăsați CTRL+V sau ⌘+V pentru a lipi aici.',
    'Screenshot uploaded successfully.' => 'Captura de ecran a fost încărcată.',
    'SEK - Swedish Krona' => 'SEK - coroană suedeză',
    'Identifier' => 'Identificator',
    'Disable two factor authentication' => 'Dezactivează autentificarea în doi factori',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Vrei să dezactivezi autentificarea în doi factori pentru utilizatorul: "%s" ?',
    'Edit link' => 'Modifică o legătură',
    'Start to type task title...' => 'Scrie titlul sarcinii…',
    'A task cannot be linked to itself' => 'O sarcină nu se poate lega de ea însăși',
    'The exact same link already exists' => 'O legătură identică există deja',
    'Recurrent task is scheduled to be generated' => 'Sarcina recurentă este programată să fie generată',
    'Score' => 'Complexitate',
    'The identifier must be unique' => 'Identificatorul trebuie să fie unic',
    'This linked task id doesn\'t exists' => 'ID-ul de sarcină legat nu există',
    'This value must be alphanumeric' => 'Valoarea trebuie să fie alfanumerică',
    'Edit recurrence' => 'Modifică recurența',
    'Generate recurrent task' => 'Generează sarcină recurentă',
    'Trigger to generate recurrent task' => 'Declanșator pentru generarea sarcinii recurente',
    'Factor to calculate new due date' => 'Factor de calculare a noii date scadente',
    'Timeframe to calculate new due date' => 'Interval de timp pentru calcularea noii date scadente',
    'Base date to calculate new due date' => 'Data de bază pentru calcularea noii date scadente',
    'Action date' => 'Data acțiunii',
    'Base date to calculate new due date: ' => 'Data de bază pentru calcularea noii date scadente: ',
    'This task has created this child task: ' => 'Sarcina aceasta a creat această sarcină-moștenitor: ',
    'Day(s)' => 'Zi(le)',
    'Existing due date' => 'Dată scadentă existentă',
    'Factor to calculate new due date: ' => 'Factor de calculare a noii date scadente: ',
    'Month(s)' => 'Lună(/i)',
    'This task has been created by: ' => 'Această sarcină a fost creată de:',
    'Recurrent task has been generated:' => 'Sarcina recurentă a fost generată:',
    'Timeframe to calculate new due date: ' => 'Interval de timp pentru calcularea noii date scadente: ',
    'Trigger to generate recurrent task: ' => 'Declanșator pentru generarea sarcinii recurente: ',
    'When task is closed' => 'Când sarcina este închisă',
    'When task is moved from first column' => 'Când sarcina este mutată din prima coloană',
    'When task is moved to last column' => 'Când sarcina este mutată în ultima coloană',
    'Year(s)' => 'An(i)',
    'Project settings' => 'Preferințe de proiect',
    'Automatically update the start date' => 'Actualizează automat data de start',
    'iCal feed' => 'Flux iCal',
    'Preferences' => 'Preferințe',
    'Security' => 'Securitate',
    'Two factor authentication disabled' => 'Autentificare în doi factori dezactivată',
    'Two factor authentication enabled' => 'Autentificare în doi factori activată',
    'Unable to update this user.' => 'Nu am putut actualiza utilizatorul.',
    'There is no user management for personal projects.' => 'Nu poți gestiona utilizatori pentru proiecte private.',
    'User that will receive the email' => 'Utilizatorul care va primi e-mail-ul',
    'Email subject' => 'Subiectul e-mail-ului',
    'Date' => 'Data',
    'Add a comment log when moving the task between columns' => 'Înregistrează un comentariu în jurnal când se mută sarcina între coloane',
    'Move the task to another column when the category is changed' => 'Mută sarcina în altă coloană când se schimbă categoria',
    'Send a task by email to someone' => 'Trimite o sarcină prin e-mail cuiva',
    'Reopen a task' => 'Redeschide o sarcină',
    'Notification' => 'Notificare',
    '%s moved the task #%d to the first swimlane' => '%s a mutat sarcina #%d în primul culoar',
    'Swimlane' => 'Culoar',
    '%s moved the task %s to the first swimlane' => '%s a mutat sarcina %s în primul culoar',
    '%s moved the task %s to the swimlane "%s"' => '%s a mutat sarcina %s în culoarul "%s"',
    'This report contains all subtasks information for the given date range.' => 'Raportul conține toate informațiile sub-sarcinilor pentru intervalul dat.',
    'This report contains all tasks information for the given date range.' => 'Raportul conține toate informațiile sarcinilor pentru intervalul dat.',
    'Project activities for %s' => 'Activități de proiect pentru "%s"',
    'view the board on Kanboard' => 'vezi bordul în Kanboard',
    'The task has been moved to the first swimlane' => 'Sarcina a fost mutată în primul culoar',
    'The task has been moved to another swimlane:' => 'Sarcina a fost mutată în alt culoar:',
    'New title: %s' => 'Titlu nou: %s',
    'The task is not assigned anymore' => 'Sarcina nu mai este desemnată',
    'New assignee: %s' => 'Desemnat nou: %s',
    'There is no category now' => 'Nu mai există categorii acum',
    'New category: %s' => 'Categorie nouă: %s',
    'New color: %s' => 'Culoare nouă: %s',
    'New complexity: %d' => 'Complexitate nouă: %d',
    'The due date has been removed' => 'Data scadentă a fost ștearsă',
    'There is no description anymore' => 'Nu mai există o descriere',
    'Recurrence settings has been modified' => 'Preferințele de recurență au fost modificate',
    'Time spent changed: %sh' => 'Timpul petrecut s-a schimbat: %s h',
    'Time estimated changed: %sh' => 'Timpul estimat s-a schimbat: %s h',
    'The field "%s" has been updated' => 'Câmpul "%s" a fost actualizat',
    'The description has been modified:' => 'Descrierea a fost modificată',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Vrei să închizi sarcina "%s" inclusiv toate sub-sarcinile?',
    'I want to receive notifications for:' => 'Vreau sa primesc notificări pentru:',
    'All tasks' => 'Toate Sarcinile',
    'Only for tasks assigned to me' => 'Numai sarcinile atribuite mie',
    'Only for tasks created by me' => 'Numai sarcinile create de mine',
    'Only for tasks created by me and tasks assigned to me' => 'Numai sarcinile create de mine si atribuite mie.',
    '%%Y-%%m-%%d' => '%%d/%%m/%%Y',
    'Total for all columns' => 'Totalul tuturor coloanelor',
    'You need at least 2 days of data to show the chart.' => 'Ai nevoie de cel putin 2 zile de date pentru afișarea graficului.',
    '<15m' => '< 15 min',
    '<30m' => '< 30 min',
    'Stop timer' => 'Oprește cronometrul',
    'Start timer' => 'Pornețe cronometrul',
    'My activity stream' => 'Fluxul meu de activități',
    'Search tasks' => 'Caută sarcini',
    'Reset filters' => 'Resetează filtre',
    'My tasks due tomorrow' => 'Sarcinile mele scadente mâine',
    'Tasks due today' => 'Sarcini scadente astăzi',
    'Tasks due tomorrow' => 'Sarcini scadente mâine',
    'Tasks due yesterday' => 'Sarcini scadente ieri',
    'Closed tasks' => 'Sarcini închise',
    'Open tasks' => 'Sarcini deschise',
    'Not assigned' => 'Fără atribuire',
    'View advanced search syntax' => 'Vezi sintaxa de căutare avansată',
    'Overview' => 'În ansamblu',
    'Board/Calendar/List view' => 'Bord/Calendar/Listă',
    'Switch to the board view' => 'Schimbă la bord',
    'Switch to the list view' => 'Schimbă la listă',
    'Go to the search/filter box' => 'Mergi la câmpul de căutare/filtre',
    'There is no activity yet.' => 'Nu există activitate încă.',
    'No tasks found.' => 'Nu s-au găsit sarcini.',
    'Keyboard shortcut: "%s"' => 'Scurtătură tastatură : "%s"',
    'List' => 'Listă',
    'Filter' => 'Filtru',
    'Advanced search' => 'Căutare avansată',
    'Example of query: ' => 'Exemplu de interogare: ',
    'Search by project: ' => 'Caută după proiect: ',
    'Search by column: ' => 'Caută după coloană: ',
    'Search by assignee: ' => 'Caută după desemnat: ',
    'Search by color: ' => 'Caută după culoare: ',
    'Search by category: ' => 'Caută după categorie: ',
    'Search by description: ' => 'Caută după descriere: ',
    'Search by due date: ' => 'Caută după dată scadentă: ',
    'Average time spent in each column' => 'Timp mediu petrecut în fiecare coloană',
    'Average time spent' => 'Timp mediu utilizat',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Acest grafic arată timpul mediu petrecut în fiecare coloană pentru ultimele %d sarcini.',
    'Average Lead and Cycle time' => 'Durată medie de Avans si Ciclu',
    'Average lead time: ' => 'Medie durată avans: ',
    'Average cycle time: ' => 'Medie durata ciclu: ',
    'Cycle Time' => 'Timp ciclu',
    'Lead Time' => 'Timp avans',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Acest grafic arată media duratelor de avans și ciclu pentru ultimele %d sarcini de-a lungul timpului.',
    'Average time into each column' => 'Durată medie în fiecare coloană',
    'Lead and cycle time' => 'Timpuri de avans și ciclu',
    'Lead time: ' => 'Timp avans: ',
    'Cycle time: ' => 'Timp ciclu: ',
    'Time spent in each column' => 'Timp petrecut prin fiecare coloană',
    'The lead time is the duration between the task creation and the completion.' => 'Timpul de avans este durata între crearea sarcinii și finalizarea.',
    'The cycle time is the duration between the start date and the completion.' => 'Timpul de ciclu este durata între data de pornire și finalizare.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Dacă sarcina nu este închisă data curentă este folosită în locul dății de finalizare.',
    'Set the start date automatically' => 'Setează automat data pornirii.',
    'Edit Authentication' => 'Modifică autentificarea',
    'Remote user' => 'Utilizator la distanță',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Utilizatorii la distanță nu păstrează parola în baza de date locală, de exemplu : conturi LDAP, GitHub sau Google.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Dacă bifezi "Interzice formularul de autentificare", acreditările introduse în dialogul de conectare vor fi ignorate.',
    'Default task color' => 'Culoarea implicită a sarcinii',
    'This feature does not work with all browsers.' => 'Această funcționalitate nu funcționează cu toate browserele.',
    'There is no destination project available.' => 'Nu este disponibil un proiect destinație.',
    'Trigger automatically subtask time tracking' => 'Declanșează automat cronometrarea timpului în sub-sarcini.',
    'Include closed tasks in the cumulative flow diagram' => 'Include sarcini închise în graficul fluxurilor cumulate',
    'Current swimlane: %s' => 'Culoarul curent: %s',
    'Current column: %s' => 'Coloana curentă: %s',
    'Current category: %s' => 'Categoria curentă: %s',
    'no category' => 'fără categorie',
    'Current assignee: %s' => 'Desemnat curent: %s',
    'not assigned' => 'fără desemnare',
    'Author:' => 'Autor:',
    'contributors' => 'contribuitori',
    'License:' => 'Licență:',
    'License' => 'Licență',
    'Enter the text below' => 'Introdu textul mai jos',
    'Start date:' => 'Data pornirii:',
    'Due date:' => 'Data scadentă:',
    'People who are project managers' => 'Persoane care gestionează proiectul',
    'People who are project members' => 'Persoane care participă la proiect',
    'NOK - Norwegian Krone' => 'NOK - Coroană norvegiană',
    'Show this column' => 'Arată această coloană',
    'Hide this column' => 'Ascunde această coloană',
    'End date' => 'Dată finalizare',
    'Users overview' => 'Prezentare generală utilizatori',
    'Members' => 'Membrii',
    'Shared project' => 'Proiect partajat',
    'Project managers' => 'Manageri de proiect',
    'Projects list' => 'Listă proiecte',
    'End date:' => 'Dată finalizare:',
    'Change task color when using a specific task link' => 'Schimbă culoarea sarcinii când se folosește o anumită legătură în sarcină',
    'Task link creation or modification' => 'Creare sau modificare legături sarcină',
    'Milestone' => 'Țel',
    'Reset the search/filter box' => 'Resetează dialogul de căutare/filtre',
    'Documentation' => 'Documentație',
    'Author' => 'Autor',
    'Version' => 'Versiuni',
    'Plugins' => 'Extensii',
    'There is no plugin loaded.' => 'Nu sunt încărcate extensii.',
    'My notifications' => 'Notificările mele',
    'Custom filters' => 'Filtre personalizate',
    'Your custom filter has been created successfully.' => 'Filtrul tău personalizat a fost creat.',
    'Unable to create your custom filter.' => 'Nu am putut crea filtrul tău personalizat.',
    'Custom filter removed successfully.' => 'Filtrul personalizat a fost șters.',
    'Unable to remove this custom filter.' => 'Nu am putut șterge filtrul presonalizat.',
    'Edit custom filter' => 'Modifică un filtru personalizat',
    'Your custom filter has been updated successfully.' => 'Filtrul tău personalizat a fost actualizat.',
    'Unable to update custom filter.' => 'Nu am putut actualiza filtrul personalizat.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Atașament nou în sarcina #%d: %s',
    'New comment on task #%d' => 'Comentariu nou în sarcina #%d',
    'Comment updated on task #%d' => 'Comentariu actualizat în sarcina #%d',
    'New subtask on task #%d' => 'Sub-sarcină nouă în sarcina #%d',
    'Subtask updated on task #%d' => 'Sub-sarcină actualizată în sarcina #%d',
    'New task #%d: %s' => 'Sarcină nouă #%d: %s',
    'Task updated #%d' => 'Sarcina #%d a fost actualizată',
    'Task #%d closed' => 'Sarcina #%d a fost închisă',
    'Task #%d opened' => 'Sarcina #%d a fost deschisă',
    'Column changed for task #%d' => 'Coloană schimbată pentru sarcina #%d',
    'New position for task #%d' => 'Poziție nouă pentru sarcina #%d',
    'Swimlane changed for task #%d' => 'Culoarul schimbat pentru sarcina #%d',
    'Assignee changed on task #%d' => 'Persoana desemnată a fost schimbată în sarcina #%d',
    '%d overdue tasks' => '%d sarcini întârziate',
    'No notification.' => 'Fără notificări.',
    'Mark all as read' => 'Marchează toate ca citite',
    'Mark as read' => 'Marchează citit',
    'Total number of tasks in this column across all swimlanes' => 'Număr total de sarcini în această coloană peste toate culoarele',
    'Collapse swimlane' => 'Restrânge culoarul',
    'Expand swimlane' => 'Extinde culoarul',
    'Add a new filter' => 'Adaugă un filtru nou',
    'Share with all project members' => 'Partajează cu toți membrii proiectului',
    'Shared' => 'Partajat',
    'Owner' => 'Proprietar',
    'Unread notifications' => 'Notificări necitite',
    'Notification methods:' => 'Metode de notificare:',
    'Unable to read your file' => 'Nu am putut citi fișierul',
    '%d task(s) have been imported successfully.' => 'Sarcini importate cu succes: %d.',
    'Nothing has been imported!' => 'Nu s-a importat nimic!',
    'Import users from CSV file' => 'Importă utilizatori dintr-un fișier CSV',
    '%d user(s) have been imported successfully.' => 'Utilizatori importați cu succes: %d.',
    'Comma' => 'Virgulă',
    'Semi-colon' => 'Punct și virgulă',
    'Tab' => 'Tab',
    'Vertical bar' => 'Bară verticală',
    'Double Quote' => 'Ghilimele duble',
    'Single Quote' => 'Ghilimele simple',
    '%s attached a file to the task #%d' => '%s a atașat un fișier sarcinii #%d',
    'There is no column or swimlane activated in your project!' => 'Nu există vreo coloană sau culoar activ în proiectul tău!',
    'Append filter (instead of replacement)' => 'Adaugă filtru (în loc de înlocuire)',
    'Append/Replace' => 'Adaugă/Înlocuiește',
    'Append' => 'Adaugă',
    'Replace' => 'Înlocuiește',
    'Import' => 'Import',
    'Change sorting' => 'Schimbă ordonarea',
    'Tasks Importation' => 'Import de sarcini',
    'Delimiter' => 'Delimitare',
    'Enclosure' => 'Caractere de încadrare',
    'CSV File' => 'Fișier CSV',
    'Instructions' => 'Instrucțiuni',
    'Your file must use the predefined CSV format' => 'Trebuie să folosești formatarea CSV predefinită',
    'Your file must be encoded in UTF-8' => 'Fișierul trebuie să fie codificat în UTF-8',
    'The first row must be the header' => 'Primul rând trebuie să fie antetul',
    'Duplicates are not verified for you' => 'Nu este verificată existența duplicatelor',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Data scadentă trebuie să folosească formatarea ISO : AAAA-LL-ZZ',
    'Download CSV template' => 'Descarcă modelul CSV',
    'No external integration registered.' => 'Nu a fost înregistrată o integrare externă.',
    'Duplicates are not imported' => 'Duplicatele nu sunt importate',
    'Usernames must be lowercase and unique' => 'Numele de utilizator trebuie să aibă caractere minuscule și să fie unice',
    'Passwords will be encrypted if present' => 'Parolele vor fi criptate dacă există',
    '%s attached a new file to the task %s' => '%s a atașat un fișier nou la sarcina %s',
    'Link type' => 'Tip de legătură',
    'Assign automatically a category based on a link' => 'Desemnează categoria automat în funcție de legătură',
    'BAM - Konvertible Mark' => 'BAM - Marcă bosniană convertibilă',
    'Assignee Username' => 'Utilizatorul desemnat',
    'Assignee Name' => 'Numele desemnatului',
    'Groups' => 'Groupuri',
    'Members of %s' => 'Membri al %s',
    'New group' => 'Grup nou',
    'Group created successfully.' => 'Grupul a fost creat.',
    'Unable to create your group.' => 'Nu am putut crea grupul.',
    'Edit group' => 'Modifică grup',
    'Group updated successfully.' => 'Grupul a fost actualizat.',
    'Unable to update your group.' => 'Nu am putut actualiza grupul.',
    'Add group member to "%s"' => 'Adaugă membru de grup în "%s"',
    'Group member added successfully.' => 'Membru de grup adăugat.',
    'Unable to add group member.' => 'Nu am putut adăuga membrul de grup.',
    'Remove user from group "%s"' => 'Șterge utilizatorul din grupul "%s"',
    'User removed successfully from this group.' => 'Utilizatorul a fost șters din grup.',
    'Unable to remove this user from the group.' => 'Nu am putut șterge utilizatorul din grup.',
    'Remove group' => 'Șterge grupul',
    'Group removed successfully.' => 'Grupul a fost șters.',
    'Unable to remove this group.' => 'Nu am putut șterge grupul.',
    'Project Permissions' => 'Permisiunile proiectului',
    'Manager' => 'Gestionar',
    'Project Manager' => 'Șef de proiect',
    'Project Member' => 'Membru de proiect',
    'Project Viewer' => 'Vizualizator de proiect',
    'Your account is locked for %d minutes' => 'Contul tău este blocat %d minute',
    'Invalid captcha' => 'Captcha invalid',
    'The name must be unique' => 'Numele trebuie să fie unic',
    'View all groups' => 'Vezi toate grupurile',
    'There is no user available.' => 'Nu există utilizator disponibil',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Vrei să ștergi utilizatorul "%s" din grupul "%s" ?',
    'There is no group.' => 'Nu există grup.',
    'Add group member' => 'Adaugă membru în grup',
    'Do you really want to remove this group: "%s"?' => 'Vrei să ștergi acest grup: "%s" ?',
    'There is no user in this group.' => 'Nu există utilizatori în acest grup',
    'Permissions' => 'Permisiuni',
    'Allowed Users' => 'Utilizatori autorizați',
    'No specific user has been allowed.' => 'Nu a fost autorizat vreun utilizator.',
    'Role' => 'Rol',
    'Enter user name...' => 'Introdu numele de utilizator…',
    'Allowed Groups' => 'Grupuri autorizate',
    'No group has been allowed.' => 'Nu a fost autorizat vreun grup.',
    'Group' => 'Grup',
    'Group Name' => 'Nume grup',
    'Enter group name...' => 'Introdu numele de grup…',
    'Role:' => 'Rol:',
    'Project members' => 'Membri de proiect',
    '%s mentioned you in the task #%d' => '%s te-a menționat în sarcina #%d',
    '%s mentioned you in a comment on the task #%d' => '%s te-a menționat într-un comentariu în sarcina #%d',
    'You were mentioned in the task #%d' => 'Ai fost menționat în sarcina #%d',
    'You were mentioned in a comment on the task #%d' => 'Ai fost menționat într-un comentariu în sarcina #%d',
    'Estimated hours: ' => 'Ore estimate: ',
    'Actual hours: ' => 'Ore actuale: ',
    'Hours Spent' => 'Ore petrecute',
    'Hours Estimated' => 'Ore estimate',
    'Estimated Time' => 'Timp estimat',
    'Actual Time' => 'Timp actual',
    'Estimated vs actual time' => 'Timp estimat vs actual',
    'RUB - Russian Ruble' => 'RUB - Rublă rusească',
    'Assign the task to the person who does the action when the column is changed' => 'Atribuie sarcina persoanei care acționează când este schimbată coloana',
    'Close a task in a specific column' => 'Închide o sarcină într-o anumită coloană',
    'Time-based One-time Password Algorithm' => 'Parolă de unică folosință bazată pe timp',
    'Two-Factor Provider: ' => 'Furnizor autentificare în doi factori: ',
    'Disable two-factor authentication' => 'Dezactivează autentificarea în doi factori',
    'Enable two-factor authentication' => 'Activează autentificarea în doi factori',
    'There is no integration registered at the moment.' => 'Nu este vreo integrare înregistrată momentan.',
    'Password Reset for Kanboard' => 'Resetare parolă pentru Kanboard',
    'Forgot password?' => 'Parolă uitată?',
    'Enable "Forget Password"' => 'Activează "Parolă Uitată"',
    'Password Reset' => 'Resetare de parolă',
    'New password' => 'Parolă nouă',
    'Change Password' => 'Schimbă parola',
    'To reset your password click on this link:' => 'Pentru a reseta parola apasă pe acest link:',
    'Last Password Reset' => 'Ultima resetare de parolă',
    'The password has never been reinitialized.' => 'Parola nu a fost resetată vreodată.',
    'Creation' => 'Creare',
    'Expiration' => 'Expirare',
    'Password reset history' => 'Istoricul resetărilor de parolă',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Toate sarcinile coloanei "%s" si a culoarului "%s" au fost închise.',
    'Do you really want to close all tasks of this column?' => 'Vrei să închizi toate sarcinile acestei coloane?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d sarcini în coloana "%s" si culoarul "%s" vor fi închise.',
    'Close all tasks in this column and this swimlane' => 'Închide toate sarcinile acestei coloane',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nici o extensie nu a înregistrat o metodă de notificare a proiectelor. Mai poți însă configura notificări individuale în profilul tău de utilizator.',
    'My dashboard' => 'Bordul meu',
    'My profile' => 'Profilul meu',
    'Project owner: ' => 'Responsabil de proiect: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Identificatorul de proiect este opțional și trebuie să fie alfanumeric, exemplu: PROIECTULMEU.',
    'Project owner' => 'Responsabil de proiect',
    'Personal projects do not have users and groups management.' => 'Proiectele private nu au utilizatori și gestionare de grupuri.',
    'There is no project member.' => 'Nu există membri de proiect.',
    'Priority' => 'Prioritate',
    'Task priority' => 'Priorități de sarcini',
    'General' => 'General',
    'Dates' => 'Date',
    'Default priority' => 'Prioritate implicită',
    'Lowest priority' => 'Prioritate mică',
    'Highest priority' => 'Prioritate maximă',
    'Close a task when there is no activity' => 'Închide o sarcină când nu are activitate',
    'Duration in days' => 'Durată în zile',
    'Send email when there is no activity on a task' => 'Trimite e-mail când o sarcină nu are activitate',
    'Unable to fetch link information.' => 'Nu am putut aduce informația legăturii.',
    'Daily background job for tasks' => 'Funcția zilnică de fundal pentru sarcini',
    'Auto' => 'Auto',
    'Related' => 'Asociat',
    'Attachment' => 'Atașament',
    'Title not found' => 'Titlul nu a fost găsit',
    'Web Link' => 'Link web',
    'External links' => 'Legături externe',
    'Add external link' => 'Adaugă legătură externă',
    'Type' => 'Tip',
    'Dependency' => 'Dependență',
    'Add internal link' => 'Adaugă legătură internă',
    'Add a new external link' => 'Adaugă o legătură externă nouă',
    'Edit external link' => 'Modifică legătura externă',
    'External link' => 'Legătură externă',
    'Copy and paste your link here...' => 'Lipește link-ul tău aici…',
    'URL' => 'URL',
    'Internal links' => 'Legături interne',
    'Assign to me' => 'Atribuie mie',
    'Me' => 'Eu',
    'Do not duplicate anything' => 'Nu duplica nimic',
    'Projects management' => 'Gestionează proiecte',
    'Users management' => 'Gestionează utilizatori',
    'Groups management' => 'Gestionează grupuri',
    'Create from another project' => 'Creează din alt proiect',
    'open' => 'deschis',
    'closed' => 'închis',
    'Priority:' => 'Prioritate:',
    'Reference:' => 'Referință:',
    'Complexity:' => 'Complexitate:',
    'Swimlane:' => 'Culoar:',
    'Column:' => 'Coloană:',
    'Position:' => 'Poziție:',
    'Creator:' => 'Creator:',
    'Time estimated:' => 'Timp estimat:',
    '%s hours' => '%s ore',
    'Time spent:' => 'Timp petrecut:',
    'Created:' => 'Creat de:',
    'Modified:' => 'Modificat:',
    'Completed:' => 'Finalizat:',
    'Started:' => 'Pornit:',
    'Moved:' => 'Mutat: ',
    'Task #%d' => 'Sarcina #%d',
    'Time format' => 'Format oră',
    'Start date: ' => 'Data pornirii: ',
    'End date: ' => 'Data finalizării: ',
    'New due date: ' => 'Dată scadentă nouă: ',
    'Start date changed: ' => 'Data pornirii modificată: ',
    'Disable personal projects' => 'Dezactivează proiectele private',
    'Do you really want to remove this custom filter: "%s"?' => 'Vrei să ștergi filtrul personalizat: "%s" ?',
    'Remove a custom filter' => 'Șterge un filtru personalizat',
    'User activated successfully.' => 'Utilizatorul a fost activat.',
    'Unable to enable this user.' => 'Nu am putut activa utilizatorul.',
    'User disabled successfully.' => 'Utilizatorul a fost dezactivat.',
    'Unable to disable this user.' => 'Nu am putut dezactiva utilizatorul.',
    'All files have been uploaded successfully.' => 'Toate fișierele au fost încărcate.',
    'The maximum allowed file size is %sB.' => 'Dimensiunea maximă a fișierului este %sB.',
    'Drag and drop your files here' => 'Trage fișierele tale aici',
    'choose files' => 'alege fișiere',
    'View profile' => 'Vezi profilul',
    'Two Factor' => 'Doi Factori',
    'Disable user' => 'Dezactivează utilizator',
    'Do you really want to disable this user: "%s"?' => 'Vrei să dezactivezi utilizatorul: "%s" ?',
    'Enable user' => 'Activează utilizator',
    'Do you really want to enable this user: "%s"?' => 'Vrei să activezi utilizatorul: "%s" ?',
    'Download' => 'Descarcă',
    'Uploaded: %s' => 'Încărcat: %s',
    'Size: %s' => 'Dimensiune: %s',
    'Uploaded by %s' => 'Încărcat de %s',
    'Filename' => 'Nume fișier',
    'Size' => 'Dimensiune',
    'Column created successfully.' => 'Coloana a fost creată.',
    'Another column with the same name exists in the project' => 'Există o coloană cu același nume în proiect',
    'Default filters' => 'Filtre implicite',
    'Your board doesn\'t have any columns!' => 'Bordul tău nu are coloane!',
    'Change column position' => 'Schimbă poziția coloanei',
    'Switch to the project overview' => 'Treci la vederea de ansamblu a proiectului',
    'User filters' => 'Filtre utilizatori',
    'Category filters' => 'Filtre categorii',
    'Upload a file' => 'Încarcă un fișier',
    'View file' => 'Vezi fișier',
    'Last activity' => 'Ultima activitate',
    'Change subtask position' => 'Schimbă poziția sub-sarcinii',
    'This value must be greater than %d' => 'Valoarea aceasta trebuie să fie mai mare decât %d',
    'Another swimlane with the same name exists in the project' => 'Există un culoar cu același nume în proiect',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Exemplu : https://exemplu.kanboard.org/ (utilizat în generarea URL-urilor absolute)',
    'Actions duplicated successfully.' => 'Acțiuni duplicate cu succes.',
    'Unable to duplicate actions.' => 'Nu am putut duplica acțiunile.',
    'Add a new action' => 'Adaugă o nouă acțiune',
    'Import from another project' => 'Importă din alt proiect',
    'There is no action at the moment.' => 'Nu există vreo acțiune momentan.',
    'Import actions from another project' => 'Importă acșiuni din alt proiect',
    'There is no available project.' => 'Nu există un proiect disponibil.',
    'Local File' => 'Fișier local',
    'Configuration' => 'Configurație',
    'PHP version:' => 'Versiune de PHP:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Versiune sistem de operare:',
    'Database version:' => 'Versiune bază de date:',
    'Browser:' => 'Browser:',
    'Task view' => 'Detaliere sarcină',
    'Edit task' => 'Modifică sarcina',
    'Edit description' => 'Modifică descrierea',
    'New internal link' => 'Legătură internă nouă',
    'Display list of keyboard shortcuts' => 'Afișează lista de scurtături pe tastatură',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Încarcă o imagine de avatar',
    'Remove my image' => 'Șterge imaginea mea',
    'The OAuth2 state parameter is invalid' => 'Parametrul "Stare" din OAuth2 este invalid',
    'User not found.' => 'Utilizatorul nu a fost găsit.',
    'Search in activity stream' => 'Caută în fluxul de activități',
    'My activities' => 'Activitățile mele',
    'Activity until yesterday' => 'Activitate până ieri',
    'Activity until today' => 'Activitate până azi',
    'Search by creator: ' => 'Caută după creator: ',
    'Search by creation date: ' => 'Caută după data creării: ',
    'Search by task status: ' => 'Caută după starea sarcinii: ',
    'Search by task title: ' => 'Caută după titlul sarcinii: ',
    'Activity stream search' => 'Căutare în fluxul de activități',
    'Projects where "%s" is manager' => 'Proiecte unde "%s" este gestionar',
    'Projects where "%s" is member' => 'Proiecte unde "%s" este membru',
    'Open tasks assigned to "%s"' => 'Sarcini deschise atribuite lui "%s"',
    'Closed tasks assigned to "%s"' => 'Sarcini închise atribuite lui "%s"',
    'Assign automatically a color based on a priority' => 'Atribuie în mod automat o culoare în funcție de prioritate',
    'Overdue tasks for the project(s) "%s"' => 'Sarcini întârziate pentru proiect "%s"',
    'Upload files' => 'Încarcă fișiere',
    'Installed Plugins' => 'Extensii instalate',
    'Plugin Directory' => 'Director extensii',
    'Plugin installed successfully.' => 'Extensie instalată cu succes.',
    'Plugin updated successfully.' => 'Extensie actualizată cu succes.',
    'Plugin removed successfully.' => 'Extensie dezinstalată cu succes.',
    'Subtask converted to task successfully.' => 'Sub-sarcina a fost transformată în sarcină.',
    'Unable to convert the subtask.' => 'Nu am putut transforma sub-sarcina.',
    'Unable to extract plugin archive.' => 'Nu am putut extrage arhiva extensiei.',
    'Plugin not found.' => 'Extensia nu a fost găsită.',
    'You don\'t have the permission to remove this plugin.' => 'Nu ai dreptul să ștergi această extensie.',
    'Unable to download plugin archive.' => 'Nu am putut descărca arhiva extensiei.',
    'Unable to write temporary file for plugin.' => 'Nu am putut scrie fișierul temporar pentru extensie.',
    'Unable to open plugin archive.' => 'Nu am putut deschide arhiva extensiei.',
    'There is no file in the plugin archive.' => 'Nu există fișiere în arhiva extensiei.',
    'Create tasks in bulk' => 'Creează sarcini în vrac',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Instanța ta de Kanboard nu a fost configurată pentru a instala extensii din interfața de utilizator.',
    'There is no plugin available.' => 'Nu există extensii disponibile.',
    'Install' => 'Instalează',
    'Update' => 'Actualizează',
    'Up to date' => 'La zi',
    'Not available' => 'Indisponibil',
    'Remove plugin' => 'Șterge extensia',
    'Do you really want to remove this plugin: "%s"?' => 'Vrei să ștergi această extensie: "%s" ?',
    'Uninstall' => 'Dezinstalare',
    'Listing' => 'Listare',
    'Metadata' => 'Metadate',
    'Manage projects' => 'Gestionează proiecte',
    'Convert to task' => 'Transformă în sarcină',
    'Convert sub-task to task' => 'Transformă sub-sarcina în sarcină',
    'Do you really want to convert this sub-task to a task?' => 'Vrei să transformi sub-sarcina în sarcină?',
    'My task title' => 'Titlul pentru sarcină',
    'Enter one task by line.' => 'Introdu o sarcină per linie.',
    'Number of failed login:' => 'Număr de autentificări eșuate:',
    'Account locked until:' => 'Cont blocat până la:',
    'Email settings' => 'Preferințe e-mail',
    'Email sender address' => 'Adresa e-mail expeditor',
    'Email transport' => 'Transport e-mail',
    'Webhook token' => 'Token de securitate webhook',
    'Project tags management' => 'Gestionare etichete de proiect',
    'Tag created successfully.' => 'Etichetă creată.',
    'Unable to create this tag.' => 'Nu am putut crea eticheta.',
    'Tag updated successfully.' => 'Eticheta a fost actualizată.',
    'Unable to update this tag.' => 'Nu am putut actualiza eticheta.',
    'Tag removed successfully.' => 'Eticheta a fost ștearsă.',
    'Unable to remove this tag.' => 'Impossible de supprimer ce libellé.',
    'Global tags management' => 'Gestionare etichete globale',
    'Tags' => 'Etichete',
    'Tags management' => 'Gestionare etichete',
    'Add new tag' => 'Adaugă etichetă nouă',
    'Edit a tag' => 'Modifică o etichetă',
    'Project tags' => 'Etichetele proiectului',
    'There is no specific tag for this project at the moment.' => 'Proiectul nu are vreo etichetă specifică momentan.',
    'Tag' => 'Etichetă',
    'Remove a tag' => 'Șterge o etichetă',
    'Do you really want to remove this tag: "%s"?' => 'Vrei să ștergi eticheta: "%s" ?',
    'Global tags' => 'Etichete globale',
    'There is no global tag at the moment.' => 'Nu există etichete globale momentan.',
    'This field cannot be empty' => 'Acest câmp nu poate fi gol',
    'Close a task when there is no activity in a specific column' => 'Închide o sarcină când nu există activitate într-o anumită coloană',
    '%s removed a subtask for the task #%d' => '%s a șters o sub-sarcină din sarcina#%d',
    '%s removed a comment on the task #%d' => '%s a șters un comentariu din sarcina #%d',
    'Comment removed on task #%d' => 'Comentariu șters în sarcina #%d',
    'Subtask removed on task #%d' => 'Sub-sarcină ștearsă din sarcina #%d',
    'Hide tasks in this column in the dashboard' => 'Ascunde sarcinile din această coloană în bord',
    '%s removed a comment on the task %s' => '%s a șters un comentariu din sarcina %s',
    '%s removed a subtask for the task %s' => '%s a șters o sub-sarcină din sarcina %s',
    'Comment removed' => 'Comentariu șters',
    'Subtask removed' => 'Sub-sarcină ștearsă',
    '%s set a new internal link for the task #%d' => '%s a definit o legătură internă nouă pentru sarcina #%d',
    '%s removed an internal link for the task #%d' => '%s a șters o legătură internă pentru sarcina #%d',
    'A new internal link for the task #%d has been defined' => 'O nouă legătură internă a fost definită pentru sarcina #%d',
    'Internal link removed for the task #%d' => 'Legătură internă ștearsă pentru sarcina #%d',
    '%s set a new internal link for the task %s' => '%s a definit o nouă legătură internă pentru sarcina %s',
    '%s removed an internal link for the task %s' => '%s a șters o legătură internă pentru sarcina %s',
    'Automatically set the due date on task creation' => 'Definește automat data scadentă la crearea sarcinii',
    'Move the task to another column when closed' => 'Mută sarcina în altă coloană când este închisă',
    'Move the task to another column when not moved during a given period' => 'Mută sarcina în altă coloană dacă nu a fost mutată într-o anumită perioadă',
    'Dashboard for %s' => 'Bordul pentru %s',
    'Tasks overview for %s' => 'Prezentare generală sarcini pentru %s',
    'Subtasks overview for %s' => 'Prezentare generală sub-sarcini pentru %s',
    'Projects overview for %s' => 'Prezentare generală proiecte pentru %s',
    'Activity stream for %s' => 'Flux de activități pentru %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Atribuie o culoare când sarcina este mutată într-un anumit culoar',
    'Assign a priority when the task is moved to a specific swimlane' => 'Atribuie o prioritate când sarcina este mutată într-un anumit culoar',
    'User unlocked successfully.' => 'Utilizatorul a fost deblocat.',
    'Unable to unlock the user.' => 'Nu am putut debloca utilizatorul.',
    'Move a task to another swimlane' => 'Mută sarcina în alt culoar',
    'Creator Name' => 'Nume creator',
    'Time spent and estimated' => 'Timp petrecut si estimat',
    'Move position' => 'Mută poziția',
    'Move task to another position on the board' => 'Mută sarcina pe altă poziție pe bord',
    'Insert before this task' => 'Inserează înaintea sarcinii',
    'Insert after this task' => 'Inserează după sarcină',
    'Unlock this user' => 'Deblochează utilizatorul',
    'Custom Project Roles' => 'Roluri personalizate în proiect',
    'Add a new custom role' => 'Adaugă rol personalizat nou',
    'Restrictions for the role "%s"' => 'Restricții pentru rolul "%s"',
    'Add a new project restriction' => 'Adaugă o restricție nouă de proiect',
    'Add a new drag and drop restriction' => 'Adaugă o restricție nouă de mutare',
    'Add a new column restriction' => 'Adaugă o restricție nouă de coloană',
    'Edit this role' => 'Modifică rolul',
    'Remove this role' => 'Șterge rolul',
    'There is no restriction for this role.' => 'Nu există restricții pe acest rol.',
    'Only moving task between those columns is permitted' => 'Sarcina poate fi mutată numai între aceste coloane',
    'Close a task in a specific column when not moved during a given period' => 'Închide o sarcină într-o anumită coloană când nu a fost mutată într-o anumită perioadă',
    'Edit columns' => 'Modifică coloane',
    'The column restriction has been created successfully.' => 'Restricția pe coloane a fost creată.',
    'Unable to create this column restriction.' => 'Nu am putut crea restricția pe coloană.',
    'Column restriction removed successfully.' => 'Restricția pe coloană a fost ștearsă.',
    'Unable to remove this restriction.' => 'Nu am putut șterge restricția.',
    'Your custom project role has been created successfully.' => 'Rolul personalizat a fost creat.',
    'Unable to create custom project role.' => 'Nu am putut crea rolul personalizat.',
    'Your custom project role has been updated successfully.' => 'Rolul personalizat a fost actualizat.',
    'Unable to update custom project role.' => 'Nu am putut actualiza rolul personalizat.',
    'Custom project role removed successfully.' => 'Rolul personalizat a fost șters.',
    'Unable to remove this project role.' => 'Nu am putut șterge rolul.',
    'The project restriction has been created successfully.' => 'Restricția pe proiect a fost creată.',
    'Unable to create this project restriction.' => 'Nu am putut crea restricția pe proiect.',
    'Project restriction removed successfully.' => 'Restricția pe proiect a fost ștearsă.',
    'You cannot create tasks in this column.' => 'Nu poți crea sarcini în această coloană.',
    'Task creation is permitted for this column' => 'Crearea sarcinilor este permisă în această coloană',
    'Closing or opening a task is permitted for this column' => 'Închiderea sau deschiderea sarcinilor este permisă în această coloană',
    'Task creation is blocked for this column' => 'Crearea sarcinilor este blocată în această coloană',
    'Closing or opening a task is blocked for this column' => 'Închiderea sau deschiderea sarcinilor este blocată în această coloană',
    'Task creation is not permitted' => 'Crearea sarcinilor nu este permisă',
    'Closing or opening a task is not permitted' => 'Închiderea sau deschiderea sarcinilor nu este permisă',
    'New drag and drop restriction for the role "%s"' => 'Restricție nouă de mutare pentru rolul "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Persoanele cu acest rol vor putea muta sarcini numai între coloana sursă și destinație.',
    'Remove a column restriction' => 'Șterge o restricție pe coloană',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Vrei să ștergi această restricție pe coloană: "%s" la "%s" ?',
    'New column restriction for the role "%s"' => 'Restricție pe coloană nouă pentru rolul "%s"',
    'Rule' => 'Reguli',
    'Do you really want to remove this column restriction?' => 'Vrei să ștergi această restricție pe coloană?',
    'Custom roles' => 'Roluri personalizate',
    'New custom project role' => 'Nou rol personalizat pe proiect',
    'Edit custom project role' => 'Modifică rol personalizat pe proiect',
    'Remove a custom role' => 'Șterge rol personalizat pe proiect',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Vrei să ștergi acest rol personalizat "%s" ? Toți membrii cu acest rol vor deveni membri de proiect.',
    'There is no custom role for this project.' => 'Nu există roluri personalizate în acest proiect.',
    'New project restriction for the role "%s"' => 'Restricție de proiect nouă pentru rolul "%s"',
    'Restriction' => 'Restricție',
    'Remove a project restriction' => 'Șterge o restricție de proiect',
    'Do you really want to remove this project restriction: "%s"?' => 'Vrei să ștergi această restricție de proiect: "%s" ?',
    'Duplicate to multiple projects' => 'Duplichează în mai multe proiecte',
    'This field is required' => 'Câmpul este obligatoriu',
    'Moving a task is not permitted' => 'Nu este permisă mutarea sarcinii',
    'This value must be in the range %d to %d' => 'Valoarea trebuie să se afle între %d și %d',
    'You are not allowed to move this task.' => 'Nu ai permisiunea să muți această sarcină.',
    'API User Access' => 'Acces utilizator in API',
    'Preview' => 'Previzualizare',
    'Write' => 'Scrie',
    'Write your text in Markdown' => 'Scrie-ți textul în Markdown',
    'No personal API access token registered.' => 'Nu este înregistrat vreun token personal de acces API.',
    'Your personal API access token is "%s"' => 'Token-ul tău personal de acces API este "%s"',
    'Remove your token' => 'Șterge token-ul tău',
    'Generate a new token' => 'Generează un nou token',
    'Showing %d-%d of %d' => 'Afișez %d - %d din %d',
    'Outgoing Emails' => 'E-mail-uri trimise',
    'Add or change currency rate' => 'Adaugă sau modifică rată de schimb',
    'Reference currency: %s' => 'Moneda de referință: %s',
    'Add custom filters' => 'Adaugă filtre personalizate',
    'Export' => 'Export',
    'Add link label' => 'Adaugă etichetă de legătură',
    'Incompatible Plugins' => 'Extensii incompatibile',
    'Compatibility' => 'Compatibilitate',
    'Permissions and ownership' => 'Permisii si proprietate',
    'Priorities' => 'Priorități',
    'Close this window' => 'Închide fereastra',
    'Unable to upload this file.' => 'Nu pot încărca fișierul acesta.',
    'Import tasks' => 'Importă sarcini',
    'Choose a project' => 'Alege un proiect',
    'Profile' => 'Profil',
    'Application role' => 'Rolul aplicației',
    '%d invitations were sent.' => '%d invitații au fost trimise.',
    '%d invitation was sent.' => '%d invitație a fost trimisă.',
    'Unable to create this user.' => 'Nu am putut crea acest utilizator.',
    'Kanboard Invitation' => 'Invitație în Kanboard',
    'Visible on dashboard' => 'Vizibil pe bord',
    'Created at:' => 'Creat la:',
    'Updated at:' => 'Actualizat la:',
    'There is no custom filter.' => 'Nu există filtru personalizat.',
    'New User' => 'Utilizator nou',
    'Authentication' => 'Autentificare',
    'If checked, this user will use a third-party system for authentication.' => 'Dacă este bifat, acest utilizator va folosi un sistem terț pentru autentificare.',
    'The password is necessary only for local users.' => 'Parola este obligatorie pentru membrii locali.',
    'You have been invited to register on Kanboard.' => 'Ai fost invitat să te înregistrezi pe Kanboard.',
    'Click here to join your team' => 'Apasă aici pentru a te alătura echipei tale',
    'Invite people' => 'Invită persoane',
    'Emails' => 'E-mail-uri',
    'Enter one email address by line.' => 'Introdu o adresă de e-mail per linie.',
    'Add these people to this project' => 'Adaugă aceste persoane în proiect',
    'Add this person to this project' => 'Adaugă această persoană în proiect',
    'Sign-up' => 'Înregistrare',
    'Credentials' => 'Acreditări',
    'New user' => 'Utilizator nou',
    'This username is already taken' => 'Acest nume de utilizator a fost luat deja',
    'Your profile must have a valid email address.' => 'Profilul tău trebuie să aibă o adresă de e-mail validă.',
    'TRL - Turkish Lira' => 'TRL - Liră turcească',
    'The project email is optional and could be used by several plugins.' => 'E-mail-ul proiectului este opțional si ar putea fi folosit de mai multe extensii.',
    'The project email must be unique across all projects' => 'E-mail-ul proiectului trebuie să fie diferit de toate celelalte proiecte.',
    'The email configuration has been disabled by the administrator.' => 'Configurarea de e-mail-uri a fost dezactivată de administrator.',
    'Close this project' => 'Închide acest proiect',
    'Open this project' => 'Deschide acest proiect',
    'Close a project' => 'Închide un proiect',
    'Do you really want to close this project: "%s"?' => 'Vrei să închizi proiectul: "%s" ?',
    'Reopen a project' => 'Redeschide un proiect',
    'Do you really want to reopen this project: "%s"?' => 'Vrei să redeschizi proiectul: "%s" ?',
    'This project is open' => 'Proiectul este deschis',
    'This project is closed' => 'Proiectul este închis',
    'Unable to upload files, check the permissions of your data folder.' => 'Nu am putut încărca fișierele, verifică permisiunile directorului de date.',
    'Another category with the same name exists in this project' => 'Altă categorie cu același nume există deja în proiect',
    'Comment sent by email successfully.' => 'Comentariul a fost trimis prin e-mail.',
    'Sent by email to "%s" (%s)' => 'Trimite prin e-mail la "%s" (%s)',
    'Unable to read uploaded file.' => 'Nu pot citi fișierul încărcat.',
    'Database uploaded successfully.' => 'Baza de date a fost încărcată cu succes.',
    'Task sent by email successfully.' => 'Sarcina a fost trimisă prin e-mail.',
    'There is no category in this project.' => 'Nu există categorii în acest proiect.',
    'Send by email' => 'Trimis prin e-mail',
    'Create and send a comment by email' => 'Creat și trimis un comentariu prin e-mail',
    'Subject' => 'Subiect',
    'Upload the database' => 'Încarcă baza de date',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Ai putea încărca baza de date Sqlite descărcată anterior (format Gzip).',
    'Database file' => 'Fișierul bazei de date',
    'Upload' => 'Încarcă',
    'Your project must have at least one active swimlane.' => 'Proiectul tău trebuie să aibă măcar un culoar activ.',
    'Project: %s' => 'Proiect: %s',
    'Automatic action not found: "%s"' => 'Acțiunea automatizată nu a fost gasită: "%s"',
    '%d projects' => '%d proiecte',
    '%d project' => '%d proiect',
    'There is no project.' => 'Nu există proiect.',
    'Sort' => 'Sortare',
    'Project ID' => 'ID-ul proiectului',
    'Project name' => 'Numele proiectului',
    'Public' => 'Public',
    'Personal' => 'Privat',
    '%d tasks' => '%d sarcini',
    '%d task' => '%d sarcină',
    'Task ID' => 'ID-ul sarcinii',
    'Assign automatically a color when due date is expired' => 'Atribuie automat o culoare când data scadentă a expirat',
    'Total score in this column across all swimlanes' => 'Scorul total în această coloană pe toate culoarele',
    'HRK - Kuna' => 'HRK - Kuna croată',
    'ARS - Argentine Peso' => 'ARS - Peso argentinian',
    'COP - Colombian Peso' => 'COP - Peso columbian',
    '%d groups' => '%d grupuri',
    '%d group' => '%d grup',
    'Group ID' => 'ID-ul grupului',
    'External ID' => 'ID extern',
    '%d users' => '%d utilizatori',
    '%d user' => '%d utilizator',
    'Hide subtasks' => 'Ascunde sub-sarcinile',
    'Show subtasks' => 'Arată sub-sarcinile',
    'Authentication Parameters' => 'Parametri de autentificare',
    'API Access' => 'Acces API',
    'No users found.' => 'Nici un utilizator găsit.',
    'User ID' => 'ID utilizator',
    'Notifications are activated' => 'Notificările sunt activate',
    'Notifications are disabled' => 'Notificările sunt dezactivate',
    'User disabled' => 'Utilizator dezactivat',
    '%d notifications' => '%d notificări',
    '%d notification' => '%d notificare',
    'There is no external integration installed.' => 'Nu este instalată vreo integrare externă.',
    'You are not allowed to update tasks assigned to someone else.' => 'Nu ai voie să actualizezi sarcini atribuite altcuiva.',
    'You are not allowed to change the assignee.' => 'Nu ai voie să schimbi persoana atribuită.',
    'Task suppression is not permitted' => 'Suprimarea sarcinii nu este permisă',
    'Changing assignee is not permitted' => 'Schimbarea persoanei atribuite nu este permisă',
    'Update only assigned tasks is permitted' => 'Numai actualizarea sarcinilor atribuite este permisă',
    'Only for tasks assigned to the current user' => 'Numai pentru sarcini atribuite utilizatorului curent',
    'My projects' => 'Proiectele mele',
    'You are not a member of any project.' => 'Nu faci parte din vreun proiect',
    'My subtasks' => 'Sub-sarcinile mele',
    '%d subtasks' => '%d sub-sarcini',
    '%d subtask' => '%d sub-sarcină',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Este permisă mutarea sarcinii între acele coloane pentru sarcinile atribuite utilizatorului curent',
    '[DUPLICATE]' => '[DUPLICAT]',
    'DKK - Danish Krona' => 'DKK - Coroană daneză',
    'Remove user from group' => 'Șterge utilizatorul din grup',
    'Assign the task to its creator' => 'Atribuie sarcina creatorului ei',
    'This task was sent by email to "%s" with subject "%s".' => 'Această sarcină a fost trimisă prin e-mail lui "%s" cu subiectul "%s".',
    'Predefined Email Subjects' => 'Subiecte predefinite in e-mail',
    'Write one subject by line.' => 'Scrie un singur subiect per linie.',
    'Create another link' => 'Creează altă legătură',
    'BRL - Brazilian Real' => 'BRL - Real brazilian',
    'Add a new Kanboard task' => 'Adaugă o nouă sarcină Kanboard',
    'Subtask not started' => 'Sub-sarcina nu este pornită',
    'Subtask currently in progress' => 'Sub-sarcină în derulare',
    'Subtask completed' => 'Sub-sarcină finalizată',
    'Subtask added successfully.' => 'Sub-sarcină adăugată.',
    '%d subtasks added successfully.' => '%d sub-sarcini au fost adăugate.',
    'Enter one subtask by line.' => 'Introdu o sub-sarcină pe linie.',
    'Predefined Contents' => 'Conținut predefinit',
    'Predefined contents' => 'Conținut predefinit',
    'Predefined Task Description' => 'Descrierea predefinită a sarcinii',
    'Do you really want to remove this template? "%s"' => 'Vrei să ștergi acest model? "%s"',
    'Add predefined task description' => 'Adaugă descriere predefinită a sarcinii',
    'Predefined Task Descriptions' => 'Descrieri predefinite ale sarcinilor',
    'Template created successfully.' => 'Model creat.',
    'Unable to create this template.' => 'Nu am putut crea modelul.',
    'Template updated successfully.' => 'Model actualizat.',
    'Unable to update this template.' => 'Nu am putut actualiza modelul.',
    'Template removed successfully.' => 'Model șters.',
    'Unable to remove this template.' => 'Nu am putut șterge modelul.',
    'Template for the task description' => 'Șablon pentru descrierea sarcinii',
    'The start date is greater than the end date' => 'Data de început este mai mare decât data de sfârșit',
    'Tags must be separated by a comma' => 'Etichetele trebuie separate prin virgulă',
    'Only the task title is required' => 'Doar titlul sarcinii este obligatoriu',
    'Creator Username' => 'Nume de utilizator creator',
    'Color Name' => 'Nume culoare',
    'Column Name' => 'Nume coloană',
    'Swimlane Name' => 'Nume culoar',
    'Time Estimated' => 'Timp estimat',
    'Time Spent' => 'Timp petrecut',
    'External Link' => 'Link extern',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Această funcție activează fluxul iCal, fluxul RSS și vizualizarea publică a tabelului.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Opriți cronometrul tuturor subsarcinilor când mutați o sarcină într-o altă coloană',
    'Subtask Title' => 'Titlu subsarcină',
    'Add a subtask and activate the timer when moving a task to another column' => 'Adaugă o subsarcină și activează cronometrul când muți o sarcină într-o altă coloană',
    'days' => 'zile',
    'minutes' => 'minute',
    'seconds' => 'secunde',
    'Assign automatically a color when preset start date is reached' => 'Atribuiți automat o culoare când se atinge data de începere prestabilită',
    'Move the task to another column once a predefined start date is reached' => 'Mutați sarcina într-o altă coloană odată ce se atinge o dată de începere predefinită',
    'This task is now linked to the task %s with the relation "%s"' => 'Această sarcină este acum legată de sarcina %s cu relația "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Legătura cu relația "%s" la sarcina %s a fost eliminată',
    'Custom Filter:' => 'Filtru personalizat:',
    'Unable to find this group.' => 'Nu găsesc acest grup.',
    '%s moved the task #%d to the column "%s"' => '%s a mutat sarcina #%d în coloana "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s a mutat sarcina #%d pe poziția %d în coloana "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s a mutat sarcina #%d în culoarul "%s"',
    '%sh spent' => '%sh petrecute',
    '%sh estimated' => '%sh estimate',
    'Select All' => 'Selectează tot',
    'Unselect All' => 'Deselectează tot',
    'Apply action' => 'Aplică acțiunea',
    'Move selected tasks to another column or swimlane' => 'Mutați sarcinile selectate într-o altă coloană sau un alt culoar',
    'Edit tasks in bulk' => 'Editați sarcinile în masă',
    'Choose the properties that you would like to change for the selected tasks.' => 'Alegeți proprietățile pe care doriți să le schimbați pentru sarcinile selectate.',
    'Configure this project' => 'Configurează acest proiect',
    'Start now' => 'Începe acum',
    '%s removed a file from the task #%d' => '%s a eliminat un fișier de la sarcina #%d',
    'Attachment removed from task #%d: %s' => 'Atașament eliminat de la sarcina #%d: %s',
    'No color' => 'Fără culoare',
    'Attachment removed "%s"' => 'Atașament eliminat "%s"',
    '%s removed a file from the task %s' => '%s a eliminat un fișier de la sarcina %s',
    'Move the task to another swimlane when assigned to a user' => 'Mutați sarcina într-un alt culoar când este atribuită unui utilizator',
    'Destination swimlane' => 'Culoar destinație',
    'Assign a category when the task is moved to a specific swimlane' => 'Atribuiți o categorie când sarcina este mutată într-un anumit culoar',
    'Move the task to another swimlane when the category is changed' => 'Mutați sarcina într-un alt culoar când categoria este schimbată',
    'Reorder this column by priority (ASC)' => 'Rearanjați această coloană după prioritate (ASC)',
    'Reorder this column by priority (DESC)' => 'Rearanjați această coloană după prioritate (DESC)',
    'Reorder this column by assignee and priority (ASC)' => 'Rearanjați această coloană după responsabil și prioritate (ASC)',
    'Reorder this column by assignee and priority (DESC)' => 'Rearanjați această coloană după responsabil și prioritate (DESC)',
    'Reorder this column by assignee (A-Z)' => 'Rearanjați această coloană după responsabil (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Rearanjați această coloană după responsabil (Z-A)',
    'Reorder this column by due date (ASC)' => 'Rearanjați această coloană după data scadenței (ASC)',
    'Reorder this column by due date (DESC)' => 'Rearanjați această coloană după data scadenței (DESC)',
    'Reorder this column by id (ASC)' => 'Rearanjați această coloană după id (ASC)',
    'Reorder this column by id (DESC)' => 'Rearanjați această coloană după id (DESC)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s a mutat sarcina #%d "%s" la proiectul "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Sarcina #%d "%s" a fost mutată la proiectul "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Mutați sarcina într-o altă coloană când data scadenței este mai mică de un anumit număr de zile',
    'Automatically update the start date when the task is moved away from a specific column' => 'Actualizați automat data de începere când sarcina este mutată din o anumită coloană',
    'HTTP Client:' => 'Client HTTP:',
    'Assigned' => 'Atribuit',
    'Task limits apply to each swimlane individually' => 'Limite sarcini se aplică fiecărui culoar individual',
    'Column task limits apply to each swimlane individually' => 'Limite sarcini coloană se aplică fiecărui culoar individual',
    'Column task limits are applied to each swimlane individually' => 'Limite sarcini coloană sunt aplicate fiecărui culoar individual',
    'Column task limits are applied across swimlanes' => 'Limite sarcini coloană sunt aplicate pe toate culoarele',
    'Task limit: ' => 'Limita sarcini:',
    'Change to global tag' => 'Schimbă în etichetă globală',
    'Do you really want to make the tag "%s" global?' => 'Sigur doriți să faceți eticheta "%s" globală?',
    'Enable global tags for this project' => 'Activează etichetele globale pentru acest proiect',
    'Group membership(s):' => 'Apartenența la grup(uri):',
    '%s is a member of the following group(s): %s' => '%s este membru al următorului(lor) grup(uri): %s',
    '%d/%d group(s) shown' => '%d/%d grup(uri) afișate',
    'Subtask creation or modification' => 'Creare sau modificare subsarcină',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Atribuiți sarcina unui utilizator specific când sarcina este mutată într-un anumit culoar',
    'Comment' => 'Comentariu',
    'Collapse vertically' => 'Strânge vertical',
    'Expand vertically' => 'Extinde vertical',
    'MXN - Mexican Peso' => 'MXN - Peso Mexican',
    'Estimated vs actual time per column' => 'Timp estimat vs timp real pe coloană',
    'HUF - Hungarian Forint' => 'HUF - Forint Maghiar',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Trebuie să selectați un fișier pentru a-l încărca drept avatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Fișierul încărcat nu este o imagine validă! (Doar *.gif, *.jpg, *.jpeg și *.png sunt permise!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Setează automat data scadenței când sarcina este mutată dintr-o anumită coloană',
    'No other projects found.' => 'Nu s-au găsit alte proiecte.',
    'Tasks copied successfully.' => 'Sarcini copiate cu succes.',
    'Unable to copy tasks.' => 'Nu se pot copia sarcinile.',
    'Theme' => 'Temă',
    'Theme:' => 'Temă:',
    'Light theme' => 'Temă deschisă',
    'Dark theme' => 'Temă închisă',
    'Automatic theme - Sync with system' => 'Temă automată - Sincronizare cu sistemul',
    'Application managers or more' => 'Manageri aplicație sau mai mult',
    'Administrators' => 'Administratori',
    'Visibility:' => 'Vizibilitate:',
    'Standard users' => 'Utilizatori standard',
    'Visibility is required' => 'Vizibilitatea este obligatorie',
    'The visibility should be an app role' => 'Vizibilitatea ar trebui să fie o rolă a aplicației',
    'Reply' => 'Răspunde',
    '%s wrote: ' => '%s a scris: ',
    'Number of visible tasks in this column and swimlane' => 'Număr de sarcini vizibile în această coloană și culoar',
    'Number of tasks in this swimlane' => 'Număr de sarcini în acest culoar',
    'Unable to find another subtask in progress, you can close this window.' => 'Nu s-a găsit altă subsarcină în progres, puteți închide această fereastră.',
    'This theme is invalid' => 'Această temă este nevalidă',
    'This role is invalid' => 'Acest rol este nevalid',
    'This timezone is invalid' => 'Acest fus orar este nevalid',
    'This language is invalid' => 'Această limbă este nevalidă',
    'This URL is invalid' => 'Această adresă URL este nevalidă',
    'Date format invalid' => 'Format dată nevalid',
    'Time format invalid' => 'Format oră nevalid',
    'Invalid Mail transport' => 'Transport Mail nevalid',
    'Color invalid' => 'Culoare nevalidă',
    'This value must be greater or equal to %d' => 'Această valoare trebuie să fie mai mare sau egală cu %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Adăugați un BOM la începutul fișierului (necesar pentru Microsoft Excel)',
    'Just add these tag(s)' => 'Doar adăugați aceste etichetă(e)',
    'Remove internal link(s)' => 'Elimină legătură(i) internă(e)',
    'Import tasks from another project' => 'Importă sarcini dintr-un alt proiect',
    'Select the project to copy tasks from' => 'Selectați proiectul din care să copiați sarcinile',
    'The total maximum allowed attachments size is %sB.' => 'Dimensiunea totală maximă permisă pentru atașamente este %sB.',
    'Add attachments' => 'Adaugă atașamente',
    'Task #%d "%s" is overdue' => 'Sarcina #%d "%s" este întârziată',
    'Enable notifications by default for all new users' => 'Activează notificările implicit pentru toți utilizatorii noi',
];
